@@ -355,9 +355,12 @@ muse_postproc_load_nearest(const cpl_propertylist *aHeader,
   } /* for iext */
   /* warn for distances larger than x arcsec */
   if (dmin * 3600. > aErrLimit) {
-    cpl_error_set_message(__func__, CPL_ERROR_INCOMPATIBLE_INPUT, "Distance of "
-                          "nearest reference table to observed position is %.2f "
-                          "arcmin, certainly a wrong reference object!", dmin * 60.);
+    char *msg = cpl_sprintf("Distance of nearest reference table to observed "
+                            "position is %.2f arcmin, certainly a wrong "
+                            "reference object!", dmin * 60.);
+    cpl_msg_error(__func__, "%s", msg);
+    cpl_error_set_message(__func__, CPL_ERROR_INCOMPATIBLE_INPUT, "%s", msg);
+    cpl_free(msg);
     return NULL;
   }
   if (dmin * 3600. > aWarnLimit) {
@@ -648,8 +651,8 @@ muse_postproc_process_exposure(muse_postproc_properties *aProp,
                                                      aProp->refframe, 20., 60.,
                                                      &raref, &decref);
     if (!reftable) {
-      cpl_msg_error(__func__, "Required input %s could not be loaded!",
-                    MUSE_TAG_STD_FLUX_TABLE);
+      cpl_msg_error(__func__, "Correct %s could not be loaded, observed "
+                    "target not listed?", MUSE_TAG_STD_FLUX_TABLE);
       muse_pixtable_delete(pt);
       return NULL;
     }
@@ -697,8 +700,8 @@ muse_postproc_process_exposure(muse_postproc_properties *aProp,
                                                      aProp->refframe, 20., 60.,
                                                      NULL, NULL);
     if (!reftable) {
-      cpl_msg_error(__func__, "Required input %s could not be loaded!",
-                    MUSE_TAG_ASTROMETRY_REFERENCE);
+      cpl_msg_error(__func__, "Correct %s could not be loaded, observed "
+                    "target not listed?", MUSE_TAG_ASTROMETRY_REFERENCE);
       muse_pixtable_delete(pt);
       return NULL;
     }
