@@ -15,15 +15,18 @@ try:
     from photutils import datasets
     from photutils import daofind
     from astropy.stats import median_absolute_deviation as mad
+    from astropy.io import fits as pyfits
+    from astropy import wcs as pywcs
 #import scikit-image
     import astropy
     import scipy
-    import pywcs # WCS conversion routines
-    import pyfits
+#    import pywcs # WCS conversion routines NOT NEEDED ANYMORE
+#    import pyfits # NOT NEEDED ANYMORE
     import copy
     import matplotlib.pyplot as plt
     import_ok = 1
-except:
+#except ImportError:
+except ImportError:
     import_ok = 0
 
 def find_closest(id_,x,y,idlist,xlist,ylist,dist_max):
@@ -196,6 +199,7 @@ if __name__ == '__main__':
   parser.add_option("-i", "--in_sof", dest="in_sof")
 #  parser.add_option("-j", "--in_dir", dest="in_dir")
   parser.add_output("-o", "--out_sof", dest="out_sof")
+  parser.add_output("-p", "--messages", dest="messages")
   inputs  = parser.get_inputs()
   outputs = parser.get_outputs()
   in_sof = inputs.in_sof#reflex.parseSofJson(json.loads(inputs.in_sof))
@@ -205,7 +209,13 @@ if __name__ == '__main__':
   if import_ok == 0:
      # print 'bu'
      # time.sleep(6)
+      #raw_input("Press enter to continue")
+#      time.sleep(6)
       outputs.out_sof = inputs.in_sof
+      outputs.messages = ('Warning: Failing in importing some required Python modules.\n Check software requirements at:\n '
+            ' https://www.eso.org/sci/software/pipelines/reflex_workflows/#software_prerequisites\n'
+            ' or in the MUSE Reflex tutorial.\n\n '
+            'Coordinates in the header will be used for alignment.\n')
       parser.write_outputs()
       sys.exit()
  
@@ -229,7 +239,7 @@ if __name__ == '__main__':
   distances=np.zeros([len(images),len(images)],float)
 
   for i in range(len(images)):
-#      print images[i], tables[i]
+     # print images[i], tables[i]
       hdu  = pyfits.open(images[i])
       image = hdu[1].data 
   
@@ -265,7 +275,8 @@ if __name__ == '__main__':
           x=np.array(junk['xcentroid'])
           y=np.array(junk['ycentroid'])
           id_=np.array(junk['id'])
-          sky = wcs.wcs_pix2sky(x,y,1)
+ #         sky = wcs.wcs_pix2sky(x,y,1)
+          sky = wcs.wcs_pix2world(x,y,1)
           sources.append([id_,sky[0],sky[1]])
       except KeyError:
           sources.append([np.array([-1]),np.array([-999]),np.array([-999])])
