@@ -3,8 +3,14 @@
 import reflex 
 import sys
 import os
-import pyfits
-import math
+try: 
+    import pyfits
+    import math
+    import_ok = 1
+#except ImportError:
+except ImportError:
+    import_ok = 0
+
 
 if __name__ == '__main__':
 
@@ -25,6 +31,10 @@ if __name__ == '__main__':
   files = in_sof.files
 
   #Do the stuff
+  if import_ok == 0:
+      outputs.out_sof = inputs.in_sof
+      parser.write_outputs()
+      sys.exit()
 
   for file in files:
     if file.category == 'TRACE_TABLE_06':
